% Figure 8 in "The Limited Power of Monetary Policy in a Pandemic",
% Antoine Lepetit and Cristina Fuentes-Albero, May 2022.

%% Preparation

clear all
clc

optimal_monetary_policy;

global M_ options_ oo_;
Tsim = 1000;
options_.periods = Tsim;
options_.simul.maxit = 200; 
options_.dynatol.f = 1e-10;
options_.dynatol.x = 1e-10;

maxlag=1;
maxlead=1;
endo_simul = repmat(oo_.endo_simul(:,1),[1,Tsim+maxlag+maxlead]);
endo_simul(:,end) = oo_.endo_simul(:,end);
oo_.endo_simul = endo_simul;

% Calibrate shocks
covid_19 =[0.005;zeros(Tsim,1)];
load mu_optimal
%mu_optimal = mu_optimal(2:end);
mu = mu_optimal;

shocks = [covid_19,mu];

eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

%% Baseline

Xn_baseline = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[covid_19(h+1:end),mu(h+1:end)]];
    perfect_foresight_solver;
    
    Xn_baseline(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

%% Lockdown 75% as tight as in baseline

mu = 0.75*mu_optimal;

shocks = [covid_19,mu];

eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

oo_.endo_simul = endo_simul;
Xn_baseline_75pct = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[covid_19(h+1:end),mu(h+1:end)]];
    perfect_foresight_solver;
    
    Xn_baseline_75pct(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end



%% Lockdown 50% as tight as in baseline

mu = 0.5*mu_optimal;

shocks = [covid_19,mu];

eps_t = shocks(1:2,:);
Tshock = size(eps_t,1);
nshock = size(eps_t,2);

oo_.endo_simul = endo_simul;
Xn_baseline_50pct = endo_simul;

for h=1:Tshock
    
    display(sprintf('Now on time %d', h));
    
    options_.periods = Tsim-h+1;
    
    oo_.exo_simul = [zeros(1,nshock);eps_t(h,:);[covid_19(h+1:end),mu(h+1:end)]];
    perfect_foresight_solver;
    
    Xn_baseline_50pct(:,h+1:end) = real(oo_.endo_simul(:,2:end));
    oo_.endo_simul = real(oo_.endo_simul(:,2:end));
    
end

%% Figures

% Infections
figure(1)
plot(Xn_baseline(3,3:500),'LineWidth',3)
hold on
plot(Xn_baseline_75pct(3,3:500),'--','LineWidth',3)
hold on
plot(Xn_baseline_50pct(3,3:500),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Infections','Fontsize',16);
ylabel('Fraction of the population','Fontsize',18);
saveas(gcf,'figures/fig8_infections.eps','epsc')

% Susceptibles
figure(2)
plot(Xn_baseline(2,3:500),'LineWidth',3)
hold on
plot(Xn_baseline_75pct(2,3:500),'--','LineWidth',3)
hold on
plot(Xn_baseline_50pct(2,3:500),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Susceptibles','Fontsize',16);
ylabel('Fraction of the population','Fontsize',18);
saveas(gcf,'figures/fig8_susceptibles.eps','epsc')

% Inflation
figure(3)
plot(100*(Xn_baseline(9,3:500)-1),'LineWidth',3)
hold on
plot(100*(Xn_baseline_75pct(9,3:500)-1),'--','LineWidth',3)
hold on
plot(100*(Xn_baseline_50pct(9,3:500)-1),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Inflation','Fontsize',16);
ylabel('Percentage points (weekly)','Fontsize',18);
saveas(gcf,'figures/fig8_inflation.eps','epsc')

% Federal funds rate
figure(4)
plot(100*Xn_baseline(10,3:500),'LineWidth',3)
hold on
plot(100*Xn_baseline_75pct(10,3:500),'--','LineWidth',3)
hold on
plot(100*Xn_baseline_50pct(10,3:500),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Federal funds rate','Fontsize',16);
ylabel('Percentage points (weekly)','Fontsize',18);
saveas(gcf,'figures/fig8_ffr.eps','epsc')

% Output
figure(5)
plot(100*(Xn_baseline(11,3:500)-1),'LineWidth',3)
hold on
plot(100*(Xn_baseline_75pct(11,3:500)-1),'--','LineWidth',3)
hold on
plot(100*(Xn_baseline_50pct(11,3:500)-1),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Output','Fontsize',16);
ylabel('Percentage deviation','Fontsize',18)
saveas(gcf,'figures/fig8_output.eps','epsc')

% Consumption
figure(6)
plot(100*(Xn_baseline(13,3:500)-1),'LineWidth',3)
hold on
plot(100*(Xn_baseline_75pct(13,3:500)-1),'--','LineWidth',3)
hold on
plot(100*(Xn_baseline_50pct(13,3:500)-1),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Consumption','Fontsize',16);
ylabel('Percentage deviation','Fontsize',18);
saveas(gcf,'figures/fig8_consumption.eps','epsc')

% Real interest rate
figure(7)
plot(Xn_baseline(10,3:500-1)-(Xn_baseline(9,4:500)-1),'LineWidth',3)
hold on
plot(Xn_baseline_75pct(10,3:500-1)-(Xn_baseline_75pct(9,4:500)-1),'--','LineWidth',3)
hold on
plot(Xn_baseline_50pct(10,3:500-1)-(Xn_baseline_50pct(9,4:500)-1),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Real interest rate','Fontsize',16);
ylabel('Percentage points (weekly)','Fontsize',18);
saveas(gcf,'figures/fig8_realinterestrate.eps','epsc')

% Deaths
figure(8)
plot(Xn_baseline(5,3:500),'LineWidth',3)
hold on
plot(Xn_baseline_75pct(5,3:500),'--','LineWidth',3)
hold on
plot(Xn_baseline_50pct(5,3:500),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',18);
%ylabel('Deaths','Fontsize',16);
ylabel('Fraction of population','FontSize',18);
saveas(gcf,'figures/fig8_deaths.eps','epsc')

% Containment rate
figure(9)
plot(mu_optimal(3:500),'LineWidth',3)
hold on
plot(0.75*mu_optimal(3:500),'--','LineWidth',3)
hold on
plot(0.5*mu_optimal(3:500),'-.','LineWidth',3)
%legend('Optimal lockdown','75% optimal lockdown','50% optimal lockdown')
xlabel('Weeks','Fontsize',16);
%ylabel('Containement rate','Fontsize',16);
saveas(gcf,'figures/fig8_containmentrate.eps','epsc')